# Changelog

## 0.3.1 (May 11, 2020)

- Pin werkzeug to be able to use the atom feed.

## 0.3 (May 18, 2019)

- Ensure universal builds
- Bugfix in build program
- Better README

## Version 0.2 (February 2, 2016)

- Python 3 compatibility (thanks to Dan Bauman).
- colored error output during build, fix for Markdown-formatted item subtitles.

## Version 0.1 (September 1, 2016)

- Initial release.
